@@ -28,6 +28,7 @@ import numpy
 
 import uproot
 import uproot._awkwardforth
+from uproot.interpretation.known_forth import known_forth_of
 
 
 class AsObjects(uproot.interpretation.Interpretation):
@@ -45,14 +46,22 @@ class AsObjects(uproot.interpretation.Interpretation):
     :ref:`uproot.interpretation.objects.AsObjects.simplify` attempts to
     replace this interpretation with a faster-to-read equivalent, but not all
     data types can be simplified.
+
+    :doc:`uproot.interpretation.known_forth` defines forth code and forms for
+    special cases that will be picked up here as well
     """
 
     def __init__(self, model, branch=None):
         self._model = model
         self._branch = branch
-        self._form = None
         self._forth = True
-        self._complete_forth_code = None
+        known_forth = known_forth_of(self._model)
+        if known_forth is not None:
+            self._complete_forth_code = known_forth.forth_code
+            self._form = known_forth.awkward_form
+        else:
+            self._complete_forth_code = None
+            self._form = None
         self._forth_lock = threading.Lock()
 
     @property
@@ -80,6 +89,23 @@ class AsObjects(uproot.interpretation.Interpretation):
     def __eq__(self, other):
         return isinstance(other, AsObjects) and self._model == other._model
 
+    def __getstate__(self):
+        return {
+            k: (
+                uproot.model._LockPlaceholder()
+                if isinstance(v, uproot.model._LockPlaceholder.lock_type)
+                else v
+            )
+            for k, v in self.__dict__.items()
+        }
+
+    def __setstate__(self, state):
+        instance_data = {
+            k: threading.Lock() if isinstance(v, uproot.model._LockPlaceholder) else v
+            for k, v in state.items()
+        }
+        self.__dict__.update(instance_data)
+
     @property
     def numpy_dtype(self):
         return numpy.dtype(object)
@@ -105,6 +131,10 @@ class AsObjects(uproot.interpretation.Interpretation):
         tobject_header=False,
         breadcrumbs=(),
     ):
+        if self._form is not None:
+            awkward = uproot.extras.awkward()
+            return awkward.forms.from_dict(self._form)
+
         context = self._make_context(
             context, index_format, header, tobject_header, breadcrumbs
         )
@@ -184,7 +214,7 @@ class AsObjects(uproot.interpretation.Interpretation):
         options,
     ):
         awkward = uproot.extras.awkward()
-        import awkward.forth
+        import awkward.forth  # noqa: F811
 
         self.hook_before_basket_array(
             data=data,
@@ -495,6 +525,27 @@ input stream
 
             start = stop
 
+        # If *some* of the baskets are Awkward and *some* are not,
+        # convert the ones that are not, individually.
+        if any(
+            uproot._util.from_module(x, "awkward") for x in basket_arrays.values()
+        ) and isinstance(
+            library,
+            (
+                uproot.interpretation.library.Awkward,
+                uproot.interpretation.library.Pandas,
+            ),
+        ):
+            awkward = uproot.extras.awkward()
+            for k, v in basket_arrays.items():
+                if not uproot._util.from_module(v, "awkward"):
+                    form = json.loads(self.awkward_form(branch.file).to_json())
+                    basket_arrays[k] = (
+                        uproot.interpretation.library._object_to_awkward_array(
+                            awkward, form, v
+                        )
+                    )
+
         if len(basket_arrays) == 0:
             output = numpy.array([], dtype=self.numpy_dtype)
 
