@@ -1,4 +1,4 @@
-# BSD 3-Clause License; see https://github.com/scikit-hep/uproot4/blob/main/LICENSE
+# BSD 3-Clause License; see https://github.com/scikit-hep/uproot5/blob/main/LICENSE
 
 """
 This module defines all of the classes and functions that are needed for writing ROOT
@@ -9,8 +9,9 @@ The :doc:`uproot.writing.writable` submodule defines the entry-points for user
 interaction: :doc:`uproot.writing.writable.create`, :doc:`uproot.writing.writable.recreate`,
 and :doc:`uproot.writing.writable.update`.
 """
+from __future__ import annotations
 
-
+from uproot.writing._dask_write import dask_write
 from uproot.writing.identify import (
     to_TArray,
     to_TH1x,
@@ -51,4 +52,5 @@ __all__ = [
     "create",
     "recreate",
     "update",
+    "dask_write",
 ]
